library(utils)	

input <- readLines ("in.txt")	
print ("foo")
print (input)

source ("script2.r")